@@ -3,8 +3,6 @@ import logging
 import sys
 from typing import Literal, Optional
 
-from oembedpy.errors import URLNotFound
-
 try:
     import click
 except ModuleNotFoundError:
@@ -13,8 +11,8 @@ except ModuleNotFoundError:
     sys.exit(1)
 import httpx
 
-from . import __version__
-from .consumer import discover, parse
+from . import __version__, discovery
+from .consumer import fetch_content
 
 logger = logging.getLogger(__name__)
 
@@ -31,8 +29,8 @@ OUTPUT_FORMAT = Literal["text", "json"]
     default="text",
     help="Display JSON format.",
 )
-@click.option("--maxwidth", type=int, help="Max width for oEmbed content.")
-@click.option("--maxheight", type=int, help="Max height for oEmbed content.")
+@click.option("--max-width", type=int, help="Max width for oEmbed content.")
+@click.option("--max-height", type=int, help="Max height for oEmbed content.")
 @click.argument("url")
 @click.pass_context
 def cli(
@@ -40,8 +38,8 @@ def cli(
     version: bool,
     url: str,
     format: OUTPUT_FORMAT,
-    maxwidth: Optional[int] = None,
-    maxheight: Optional[int] = None,
+    max_width: Optional[int] = None,
+    max_height: Optional[int] = None,
 ):
     """Fetch and display oEmbed parameters from oEmbed provider."""
     if version:
@@ -51,32 +49,30 @@ def cli(
     # Fetch content to find meta tags.
     logger.debug(f"Target Content URL is {url}")
     try:
-        oembed_url = discover(url)
-    except URLNotFound as err:
+        api_url, params = discovery.find_from_content(url)
+    except Exception as err:
         logger.warn(f"oEmbed API is not found from URL: {err}")
         ctx.abort()
 
     # Fetch oEmbed content
     try:
-        api_url, params = parse(oembed_url)
-        if maxwidth:
-            params.maxwidth = maxwidth
-        if maxheight:
-            params.maxheight = maxheight
-        resp = httpx.get(api_url, params=params.to_dict())
-        resp.raise_for_status()
+        if max_width:
+            params.max_width = max_width
+        if max_height:
+            params.max_height = max_height
+        content = fetch_content(api_url, params=params)
     except httpx.HTTPError as exc:
         logger.error(f"Failed to oEmbed URL for {exc}")
         click.echo(click.style(f"Failed to oEmbed URL for {exc}", fg="red"))
         ctx.abort()
-    data = resp.json()
 
     # Display data
     if format == "json":
         logger.debug("Display as raw JSON")
-        click.echo(resp.content)
+        click.echo(content.to_dict())
     else:
         logger.debug("Display as formatted text")
+        data = content.to_dict()
         keylen = max(len(k) for k in data.keys()) + 2
         for k, v in data.items():
             click.echo(f"{(k+':'):<{keylen}}{v}")
